@@ -9,6 +9,8 @@ class SegmentDict(TypedDict, total=False):
     text: str
 
 
-class TranscriptionResult(TypedDict):
+class TranscriptionResult(TypedDict, total=False):
     text: str
     segments: list[SegmentDict]
+    # Optional: Whisper-detected language code (e.g., 'de', 'en')
+    language: str
